/*
	Paramete file for YCbCr(CCIR 601-1) to RGB-888 color space convertor
	
	File		: YCbCr2RGB_conv.h

	Designer	: Masami IKURA [ MASATIKU ]
	Organize	: KURUSUGAWA Electronics Industry Inc,.
	Revision	: Rev0.1
	Syntax		: NSL language set
	Resume		: 110517 first design.
*/

// Original equation
//	R = 1.00000*Y                   + 1.40200(Cr-128)
//	G = 1.00000*Y - 0.34414(Cb-128) - 0.71414(Cr-128)
//	B = 1.00000*Y + 1.77200(Cb-128)

// Implement equation
//	R = 1.00000*Y + 0.00000*Cb + 1.40200*Cr - 179.45600
//	G = 1.00000*Y - 0.34414*Cb - 0.71414*Cr + 135.45984
//	B = 1.00000*Y + 1.77200*Cb + 0.00000*Cr - 226.81600

//		x4096 coefficient
//		x256  constant value

// Coefficient for RED.
	#define		COEF_R1		16'h1000	// Y
	#define		COEF_R2		16'h0000	// Cb
	#define		COEF_R3		16'h166E	// Cr
	#define		COEF_R4		16'd45941	// Constant value (+)

// Coefficient for GREEN.
	#define		COEF_G1		16'h1000	// Y
	#define		COEF_G2		16'h0581	// Cb
	#define		COEF_G3		16'h0B6D	// Cr
	#define		COEF_G4		16'd34678	// Constant value (+)

// Coefficient for BLUE.
	#define		COEF_B1		16'h1000	// Y
	#define		COEF_B2		16'h1C5A	// Cb
	#define		COEF_B3		16'h0000	// Cr
	#define		COEF_B4		16'd58065	// Constant value (+)

declare YCbCr2RGB_conv {

// CCIR-656 data input
	input		Y_in[8] ;
	input		Cb_in[8] ;
	input		Cr_in[8] ;
	
// RGB-888 data output
	output		R_out[8] ;
	output		G_out[8] ;
	output		B_out[8] ;
	
// Control lines
	input		VSYNCin ;				// VSYNC in
	input		HSYNCin ;				// HSYNC in
	
	output		VSYNCout ;				// Pipeline clock conpensated VSYNC out
	output		HSYNCout ;				// Pipeline clock conpensated HSYNC out

// Function control
	func_in		ConvStart( Y_in, Cb_in, Cr_in ) ;
	func_out	ConvFinish( R_out, G_out, B_out ) ;
}
